@@ -35,7 +35,7 @@
 
  *****************************************************************************/
 
-/* 
+/*
 $Log: scx_signal_unsigned.h,v $
 Revision 1.1  2011/08/15 17:31:11  acg
  Andy Goodrich: moved specialized signals from examples to this tree.
@@ -120,7 +120,7 @@ Andy Goodrich - Forte Design Systems, Inc.
 
  *****************************************************************************/
 
-/* 
+/*
 $Log: scx_signal_unsigned.h,v $
 Revision 1.1  2011/08/15 17:31:11  acg
  Andy Goodrich: moved specialized signals from examples to this tree.
@@ -208,7 +208,7 @@ class sc_unsigned_sigref;
 // data type is sc_dt::sc_biguint<W>. This class serves as the base class for the
 // sc_dt::sc_biguint<W> specialization of the sc_signal_in_if<T> class. The methods
 // in this class may be over-ridden individually, those that are not overridden
-// will produce an error message when called. The methods are used by the 
+// will produce an error message when called. The methods are used by the
 // sc_unsigned_sigref class.
 //
 // Notes:
@@ -244,7 +244,7 @@ class sc_unsigned_part_if : virtual public sc_interface {
 //
 // This is the class specializations for the sc_signal_in_if<T> class to
 // provide additional features for sc_signal instances whose template is
-// sc_dt::sc_biguint<W>, including part access. 
+// sc_dt::sc_biguint<W>, including part access.
 //
 // Notes:
 //   (1) Descriptions of the methods and operators in this class appear with
@@ -270,12 +270,12 @@ class sc_signal_in_if<sc_dt::sc_biguint<W> > : public sc_unsigned_part_if {
     // was there a value changed event?
     virtual bool event() const = 0;
 
-  protected: 
+  protected:
     // constructor
     sc_signal_in_if()
     {}
 
-  private: // disabled 
+  private: // disabled
     sc_signal_in_if( const this_type& );
     this_type& operator = ( const this_type& );
 };
@@ -330,10 +330,10 @@ class sc_unsigned_sigref : public sc_dt::sc_unsigned_subref_r
 
 
 //==============================================================================
-// CLASS sc_signal<sc_dt::sc_biguint<W> > 
+// CLASS sc_signal<sc_dt::sc_biguint<W> >
 //
 // This class implements a signal whose value acts like an sc_dt::sc_biguint<W> data
-// value. This class is a specialization of the generic sc_signal class to 
+// value. This class is a specialization of the generic sc_signal class to
 // implement tailored support for the sc_dt::sc_biguint<W> class.
 //
 // Notes:
@@ -341,8 +341,8 @@ class sc_unsigned_sigref : public sc_dt::sc_unsigned_subref_r
 //       their implementations.
 //==============================================================================
 SC_TEMPLATE
-class sc_signal<sc_dt::sc_biguint<W> > : 
-    public sc_dt::sc_biguint<W>, 
+class sc_signal<sc_dt::sc_biguint<W> > :
+    public sc_dt::sc_biguint<W>,
 	public sc_prim_channel,
     public sc_signal_inout_if<sc_dt::sc_biguint<W> >
 {
@@ -369,7 +369,7 @@ class sc_signal<sc_dt::sc_biguint<W> > :
 
   public: // sc_interface virtual methods:
     virtual inline const sc_event& default_event() const;
-    virtual inline void register_port( 
+    virtual inline void register_port(
 		sc_port_base& port_, const char* if_typename_ );
 
   public: // sc_unsigned_channel virtual methods:
@@ -433,66 +433,66 @@ class sc_signal<sc_dt::sc_biguint<W> > :
     const sc_dt::sc_unsigned& operator -- (int); // postfix
     sc_dt::sc_unsigned& operator += (const sc_dt::sc_signed&    );
     sc_dt::sc_unsigned& operator += (const sc_dt::sc_unsigned&  );
-    sc_dt::sc_unsigned& operator += (sc_dt::int64               ); 
-    sc_dt::sc_unsigned& operator += (sc_dt::uint64              ); 
-    sc_dt::sc_unsigned& operator += (long                ); 
-    sc_dt::sc_unsigned& operator += (unsigned long       ); 
+    sc_dt::sc_unsigned& operator += (sc_dt::int64               );
+    sc_dt::sc_unsigned& operator += (sc_dt::uint64              );
+    sc_dt::sc_unsigned& operator += (long                );
+    sc_dt::sc_unsigned& operator += (unsigned long       );
     sc_dt::sc_unsigned& operator += (int                 );
     sc_dt::sc_unsigned& operator += (unsigned int        );
     sc_dt::sc_unsigned& operator -= (const sc_dt::sc_signed&    );
     sc_dt::sc_unsigned& operator -= (const sc_dt::sc_unsigned&  );
-    sc_dt::sc_unsigned& operator -= (sc_dt::int64               ); 
-    sc_dt::sc_unsigned& operator -= (sc_dt::uint64              ); 
-    sc_dt::sc_unsigned& operator -= (long                ); 
-    sc_dt::sc_unsigned& operator -= (unsigned long       ); 
+    sc_dt::sc_unsigned& operator -= (sc_dt::int64               );
+    sc_dt::sc_unsigned& operator -= (sc_dt::uint64              );
+    sc_dt::sc_unsigned& operator -= (long                );
+    sc_dt::sc_unsigned& operator -= (unsigned long       );
     sc_dt::sc_unsigned& operator -= (int                 );
     sc_dt::sc_unsigned& operator -= (unsigned int        );
     sc_dt::sc_unsigned& operator *= (const sc_dt::sc_signed&    );
     sc_dt::sc_unsigned& operator *= (const sc_dt::sc_unsigned&  );
-    sc_dt::sc_unsigned& operator *= (sc_dt::int64               ); 
-    sc_dt::sc_unsigned& operator *= (sc_dt::uint64              ); 
-    sc_dt::sc_unsigned& operator *= (long                ); 
-    sc_dt::sc_unsigned& operator *= (unsigned long       ); 
+    sc_dt::sc_unsigned& operator *= (sc_dt::int64               );
+    sc_dt::sc_unsigned& operator *= (sc_dt::uint64              );
+    sc_dt::sc_unsigned& operator *= (long                );
+    sc_dt::sc_unsigned& operator *= (unsigned long       );
     sc_dt::sc_unsigned& operator *= (int                 );
     sc_dt::sc_unsigned& operator *= (unsigned int        );
     sc_dt::sc_unsigned& operator /= (const sc_dt::sc_signed&    );
     sc_dt::sc_unsigned& operator /= (const sc_dt::sc_unsigned&  );
-    sc_dt::sc_unsigned& operator /= (sc_dt::int64               ); 
-    sc_dt::sc_unsigned& operator /= (sc_dt::uint64              ); 
-    sc_dt::sc_unsigned& operator /= (long                ); 
-    sc_dt::sc_unsigned& operator /= (unsigned long       ); 
+    sc_dt::sc_unsigned& operator /= (sc_dt::int64               );
+    sc_dt::sc_unsigned& operator /= (sc_dt::uint64              );
+    sc_dt::sc_unsigned& operator /= (long                );
+    sc_dt::sc_unsigned& operator /= (unsigned long       );
     sc_dt::sc_unsigned& operator /= (int                 );
     sc_dt::sc_unsigned& operator /= (unsigned int        );
     sc_dt::sc_unsigned& operator %= (const sc_dt::sc_signed&    );
     sc_dt::sc_unsigned& operator %= (const sc_dt::sc_unsigned&  );
-    sc_dt::sc_unsigned& operator %= (sc_dt::int64               ); 
-    sc_dt::sc_unsigned& operator %= (sc_dt::uint64              ); 
-    sc_dt::sc_unsigned& operator %= (long                ); 
-    sc_dt::sc_unsigned& operator %= (unsigned long       ); 
+    sc_dt::sc_unsigned& operator %= (sc_dt::int64               );
+    sc_dt::sc_unsigned& operator %= (sc_dt::uint64              );
+    sc_dt::sc_unsigned& operator %= (long                );
+    sc_dt::sc_unsigned& operator %= (unsigned long       );
     sc_dt::sc_unsigned& operator %= (int                 );
     sc_dt::sc_unsigned& operator %= (unsigned int        );
     sc_dt::sc_unsigned& operator &= (const sc_dt::sc_signed&    );
     sc_dt::sc_unsigned& operator &= (const sc_dt::sc_unsigned&  );
-    sc_dt::sc_unsigned& operator &= (sc_dt::int64               ); 
-    sc_dt::sc_unsigned& operator &= (sc_dt::uint64              ); 
-    sc_dt::sc_unsigned& operator &= (long                ); 
-    sc_dt::sc_unsigned& operator &= (unsigned long       ); 
+    sc_dt::sc_unsigned& operator &= (sc_dt::int64               );
+    sc_dt::sc_unsigned& operator &= (sc_dt::uint64              );
+    sc_dt::sc_unsigned& operator &= (long                );
+    sc_dt::sc_unsigned& operator &= (unsigned long       );
     sc_dt::sc_unsigned& operator &= (int                 );
     sc_dt::sc_unsigned& operator &= (unsigned int        );
     sc_dt::sc_unsigned& operator |= (const sc_dt::sc_signed&    );
     sc_dt::sc_unsigned& operator |= (const sc_dt::sc_unsigned&  );
-    sc_dt::sc_unsigned& operator |= (sc_dt::int64               ); 
-    sc_dt::sc_unsigned& operator |= (sc_dt::uint64              ); 
-    sc_dt::sc_unsigned& operator |= (long                ); 
-    sc_dt::sc_unsigned& operator |= (unsigned long       ); 
+    sc_dt::sc_unsigned& operator |= (sc_dt::int64               );
+    sc_dt::sc_unsigned& operator |= (sc_dt::uint64              );
+    sc_dt::sc_unsigned& operator |= (long                );
+    sc_dt::sc_unsigned& operator |= (unsigned long       );
     sc_dt::sc_unsigned& operator |= (int                 );
     sc_dt::sc_unsigned& operator |= (unsigned int        );
     sc_dt::sc_unsigned& operator ^= (const sc_dt::sc_signed&    );
     sc_dt::sc_unsigned& operator ^= (const sc_dt::sc_unsigned&  );
-    sc_dt::sc_unsigned& operator ^= (sc_dt::int64               ); 
-    sc_dt::sc_unsigned& operator ^= (sc_dt::uint64              ); 
-    sc_dt::sc_unsigned& operator ^= (long                ); 
-    sc_dt::sc_unsigned& operator ^= (unsigned long       ); 
+    sc_dt::sc_unsigned& operator ^= (sc_dt::int64               );
+    sc_dt::sc_unsigned& operator ^= (sc_dt::uint64              );
+    sc_dt::sc_unsigned& operator ^= (long                );
+    sc_dt::sc_unsigned& operator ^= (unsigned long       );
     sc_dt::sc_unsigned& operator ^= (int                 );
     sc_dt::sc_unsigned& operator ^= (unsigned int        );
 
@@ -572,19 +572,19 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::base_write( sc_dt::uint64 value )
 //------------------------------------------------------------------------------
 //"sc_signal<sc_dt::sc_biguint<W> >::check_writer"
 //
-// This method checks to see if there is more than one writer for this 
+// This method checks to see if there is more than one writer for this
 // object instance by keeping track of the process performing the write.
 //------------------------------------------------------------------------------
 SC_TEMPLATE
 inline void sc_signal<sc_dt::sc_biguint<W> >::check_writer()
 {
     sc_process_b* writer_p = sc_get_current_process_b();
-    if( m_writer_p == 0 ) 
-    {   
+    if( m_writer_p == 0 )
+    {
         m_writer_p = writer_p;
-    } 
-    else if( m_writer_p != writer_p ) 
-    {   
+    }
+    else if( m_writer_p != writer_p )
+    {
         sc_signal_invalid_writer( name(), kind(),
                                   m_writer_p->name(), writer_p->name() );
     }
@@ -595,10 +595,10 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::check_writer()
 //"sc_signal<sc_dt::sc_biguint<W> >::concat_set"
 //
 // These virtual methods allow value assignments to this object instance
-// from various sources. The position within the supplied source of the 
+// from various sources. The position within the supplied source of the
 // low order bit for this object instance's value is low_i.
 //     src   = source value.
-//     low_i = bit within src to serve as low order bit of this object 
+//     low_i = bit within src to serve as low order bit of this object
 //             instance's value.
 //------------------------------------------------------------------------------
 SC_TEMPLATE
@@ -611,7 +611,7 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::concat_set(sc_dt::int64 src, int l
     else
     {
         base_write( (sc_dt::int64)((src < 0 ) ?  -1 : 0 ));
-    } 
+    }
 }
 
 SC_TEMPLATE
@@ -631,7 +631,7 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::concat_set(
 }
 
 SC_TEMPLATE
-inline void sc_signal<sc_dt::sc_biguint<W> >::concat_set(	
+inline void sc_signal<sc_dt::sc_biguint<W> >::concat_set(
 	const sc_dt::sc_unsigned& src, int low_i)
 {
     base_write( (src >> low_i) );
@@ -646,7 +646,7 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::concat_set(sc_dt::uint64 src, int
 
 
 SC_TEMPLATE // Return the default event for this object instance.
-inline const sc_event& sc_signal<sc_dt::sc_biguint<W> >::default_event() const 
+inline const sc_event& sc_signal<sc_dt::sc_biguint<W> >::default_event() const
 	{ return base_value_changed_event(); }
 
 
@@ -661,7 +661,7 @@ inline const sc_dt::sc_biguint<W>& sc_signal<sc_dt::sc_biguint<W> >::get_data_re
 
 
 SC_TEMPLATE // Return a pointer to this object instance.
-inline sc_signal<sc_dt::sc_biguint<W> >& sc_signal<sc_dt::sc_biguint<W> >::get_signal() 
+inline sc_signal<sc_dt::sc_biguint<W> >& sc_signal<sc_dt::sc_biguint<W> >::get_signal()
 	{ return *this; }
 
 
@@ -707,7 +707,7 @@ SC_TEMPLATE
 inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( const this_type& new_val )
 	{ base_write( new_val ); }
 
-SC_TEMPLATE 
+SC_TEMPLATE
 inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( const char* new_val )
 	{ sc_dt::sc_biguint<W> tmp = new_val; m_new_val = tmp; request_update(); }
 
@@ -733,17 +733,17 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( int new_val )
 
 
 SC_TEMPLATE
-inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( long new_val ) 
+inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( long new_val )
 	{ base_write((sc_dt::int64)new_val); }
 
 
 SC_TEMPLATE
-inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( short new_val ) 
+inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( short new_val )
 	{ base_write((sc_dt::int64)new_val); }
 
 
 SC_TEMPLATE
-inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( unsigned int new_val ) 
+inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( unsigned int new_val )
 	{ base_write((sc_dt::int64)new_val); }
 
 
@@ -759,9 +759,9 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( unsigned short new_va
 
 SC_TEMPLATE
 template<typename T>
-inline void sc_signal<sc_dt::sc_biguint<W> >::operator = ( 
+inline void sc_signal<sc_dt::sc_biguint<W> >::operator = (
 	const sc_dt::sc_generic_base<T>& new_val )
-{ 
+{
 	sc_dt::sc_unsigned temp(W);
     new_val->to_sc_unsigned(temp);
     base_write(temp);
@@ -792,7 +792,7 @@ inline const sc_dt::sc_biguint<W>& sc_signal<sc_dt::sc_biguint<W> >::read() cons
 
 
 SC_TEMPLATE // Read a portion of a value.
-inline sc_dt::sc_unsigned sc_signal<sc_dt::sc_biguint<W> >::read_part( 
+inline sc_dt::sc_unsigned sc_signal<sc_dt::sc_biguint<W> >::read_part(
 	int left, int right ) const
 {
 	sc_dt::sc_unsigned tmp(left-right+1);
@@ -801,14 +801,14 @@ inline sc_dt::sc_unsigned sc_signal<sc_dt::sc_biguint<W> >::read_part(
 }
 
 SC_TEMPLATE
-inline void sc_signal<sc_dt::sc_biguint<W> >::register_port( 
+inline void sc_signal<sc_dt::sc_biguint<W> >::register_port(
 	sc_port_base& port_, const char* if_typename_ )
 {
 #       ifdef DEBUG_SYSTEMC
 		std::string nm( if_typename_ );
-		if( nm == typeid( sc_signal_inout_if<sc_dt::sc_biguint<W> > ).name() ) 
+		if( nm == typeid( sc_signal_inout_if<sc_dt::sc_biguint<W> > ).name() )
 		{
-			if( m_output_p != 0 ) 
+			if( m_output_p != 0 )
 			{
 				sc_signal_invalid_writer( name(), kind(),
 					 m_output_p->name(), port_.name() );
@@ -822,7 +822,7 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::register_port(
 
 
 SC_TEMPLATE // Autogenerated name object instance constructor.
-inline sc_signal<sc_dt::sc_biguint<W> >::sc_signal() : 
+inline sc_signal<sc_dt::sc_biguint<W> >::sc_signal() :
 	sc_prim_channel(sc_gen_unique_name( "signal" )),
 	m_changed_event_p(0),
 	m_new_val(W),
@@ -832,7 +832,7 @@ inline sc_signal<sc_dt::sc_biguint<W> >::sc_signal() :
 
 
 SC_TEMPLATE // Explicitly named object instance constructor.
-inline sc_signal<sc_dt::sc_biguint<W> >::sc_signal(const char* name_) : 
+inline sc_signal<sc_dt::sc_biguint<W> >::sc_signal(const char* name_) :
 	sc_prim_channel(name_),
 	m_changed_event_p(0),
 	m_new_val(W),
@@ -842,7 +842,7 @@ inline sc_signal<sc_dt::sc_biguint<W> >::sc_signal(const char* name_) :
 
 
 SC_TEMPLATE // Object instance destructor.
-inline sc_signal<sc_dt::sc_biguint<W> >::~sc_signal() 
+inline sc_signal<sc_dt::sc_biguint<W> >::~sc_signal()
 {
 	if ( m_changed_event_p ) delete m_changed_event_p;
 }
@@ -869,42 +869,42 @@ inline const sc_event& sc_signal<sc_dt::sc_biguint<W> >::value_changed_event() c
 
 
 SC_TEMPLATE // Write a sc_in<sc_dt::sc_biguint<W> > value to this object instance.
-inline void sc_signal<sc_dt::sc_biguint<W> >::write( 
-	const sc_in<sc_dt::sc_biguint<W> >& value ) 
+inline void sc_signal<sc_dt::sc_biguint<W> >::write(
+	const sc_in<sc_dt::sc_biguint<W> >& value )
 	{ base_write( value ); }
 
 
 SC_TEMPLATE // Write a sc_inout<sc_dt::sc_biguint<W> > value to this object instance.
-inline void sc_signal<sc_dt::sc_biguint<W> >::write( 
-	const sc_inout<sc_dt::sc_biguint<W> >& value ) 
+inline void sc_signal<sc_dt::sc_biguint<W> >::write(
+	const sc_inout<sc_dt::sc_biguint<W> >& value )
 { base_write( value ); }
 
 
 SC_TEMPLATE // Write a sc_dt::sc_biguint<W> value to this object instance.
-inline void sc_signal<sc_dt::sc_biguint<W> >::write( const sc_dt::sc_biguint<W>& value ) 
+inline void sc_signal<sc_dt::sc_biguint<W> >::write( const sc_dt::sc_biguint<W>& value )
 	{ base_write( value); }
 
 
-SC_TEMPLATE // Write a portion of a value. If this is the first write in 
+SC_TEMPLATE // Write a portion of a value. If this is the first write in
             // a delta cycle we copy the existing value before setting the bits.
-inline void sc_signal<sc_dt::sc_biguint<W> >::write_part(sc_dt::int64 v, int left, int right) 
+inline void sc_signal<sc_dt::sc_biguint<W> >::write_part(sc_dt::int64 v, int left, int right)
 {
 	m_new_val(left, right) = v;
 	request_update();
 }
 
 
-SC_TEMPLATE // Select a portion of a value. 
+SC_TEMPLATE // Select a portion of a value.
 inline sc_unsigned_sigref& sc_signal<sc_dt::sc_biguint<W> >::select_part(
 	int left, int right)
 {
     sc_unsigned_sigref* result_p = sc_unsigned_sigref::m_pool.allocate();
-    result_p->initialize(DCAST<sc_unsigned_part_if*>(this), left, right);
+    result_p->initialize(dynamic_cast<sc_unsigned_part_if*>(this), left, right);
     return *result_p;
 }
 
 
-SC_TEMPLATE // Write a portion of a value. If this is the first write in 
+SC_TEMPLATE // Write a portion of a value. If this is the first write in
             // a delta cycle we copy the existing value before setting the bits.
 inline void sc_signal<sc_dt::sc_biguint<W> >::write_part(sc_dt::uint64 v, int left, int right)
 {
@@ -913,20 +913,20 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::write_part(sc_dt::uint64 v, int le
 }
 
 
-SC_TEMPLATE // Write a portion of a value. If this is the first write in 
+SC_TEMPLATE // Write a portion of a value. If this is the first write in
             // a delta cycle we copy the existing value before setting the bits.
-inline void sc_signal<sc_dt::sc_biguint<W> >::write_part( 
-	const sc_dt::sc_signed& v, int left, int right ) 
+inline void sc_signal<sc_dt::sc_biguint<W> >::write_part(
+	const sc_dt::sc_signed& v, int left, int right )
 {
 	m_new_val(left, right) = v;
 	request_update();
 }
 
 
-SC_TEMPLATE // Write a portion of a value. If this is the first write in 
+SC_TEMPLATE // Write a portion of a value. If this is the first write in
             // a delta cycle we copy the existing value before setting the bits.
-inline void sc_signal<sc_dt::sc_biguint<W> >::write_part( 
-	const sc_dt::sc_unsigned& v, int left, int right ) 
+inline void sc_signal<sc_dt::sc_biguint<W> >::write_part(
+	const sc_dt::sc_unsigned& v, int left, int right )
 {
 	m_new_val(left, right) = v;
 	request_update();
@@ -937,11 +937,11 @@ inline void sc_signal<sc_dt::sc_biguint<W> >::write_part(
 // CLASS sc_in<sc_dt::sc_biguint<W> >
 //
 // This class implements an input port whose target acts like an sc_dt::sc_biguint<W> data
-// value. This class is a specialization of the generic sc_in class to 
+// value. This class is a specialization of the generic sc_in class to
 // implement tailored support for the sc_dt::sc_biguint<W> class.
 //==============================================================================
 SC_TEMPLATE
-class sc_in<sc_dt::sc_biguint<W> > : 
+class sc_in<sc_dt::sc_biguint<W> > :
     public sc_port<sc_signal_in_if<sc_dt::sc_biguint<W> >, 1,
                    SC_ONE_OR_MORE_BOUND>,
     public sc_dt::sc_value_base
@@ -964,10 +964,10 @@ class sc_in<sc_dt::sc_biguint<W> > :
 
     // bind methods and operators:
 
-    void bind( const in_if_type& interface_ ) 
-        { sc_port_base::bind( CCAST<in_if_type&>( interface_) );}
+    void bind( const in_if_type& interface_ )
+        { sc_port_base::bind( const_cast<in_if_type&>( interface_) );}
     void operator () ( const in_if_type& interface_ )
-        { sc_port_base::bind( CCAST<in_if_type&>( interface_) );}
+        { sc_port_base::bind( const_cast<in_if_type&>( interface_) );}
     void bind( in_port_type& parent_ )
         { sc_port_base::bind(parent_);}
     void operator () ( in_port_type& parent_ )
@@ -982,21 +982,21 @@ class sc_in<sc_dt::sc_biguint<W> > :
     virtual inline int vbind( sc_interface& interface_ )
         {
             return sc_port_b<if_type>::vbind( interface_ );
-        }       
+        }
     virtual inline int vbind( sc_port_base& parent_ )
         {
-            in_port_type* in_parent = DCAST<in_port_type*>( &parent_ );  
+            in_port_type* in_parent = dynamic_cast<in_port_type*>( &parent_ );
             if( in_parent != 0 ) {
                 sc_port_base::bind( *in_parent );
                 return 0;
             }
-            inout_port_type* inout_parent = DCAST<inout_port_type*>( &parent_ );
+            inout_port_type* inout_parent = dynamic_cast<inout_port_type*>( &parent_ );
             if( inout_parent != 0 ) {
                 sc_port_base::bind( *inout_parent );
                 return 0;
             }
             // type mismatch
-            return 2;     
+            return 2;
         }
 
 
@@ -1012,11 +1012,11 @@ class sc_in<sc_dt::sc_biguint<W> > :
         {}
 
     explicit sc_in( const in_if_type& interface_ )
-        : base_type( CCAST<in_if_type&>( interface_ ) ), m_traces( 0 )
+        : base_type( const_cast<in_if_type&>( interface_ ) ), m_traces( 0 )
         {}
 
-    sc_in( const char* name_, const in_if_type& interface_ )     
-        : base_type( name_, CCAST<in_if_type&>( interface_ ) ), m_traces( 0 )
+    sc_in( const char* name_, const in_if_type& interface_ )
+        : base_type( name_, const_cast<in_if_type&>( interface_ ) ), m_traces( 0 )
         {}
 
     explicit sc_in( in_port_type& parent_ )
@@ -1024,7 +1024,7 @@ class sc_in<sc_dt::sc_biguint<W> > :
         {}
 
     sc_in( const char* name_, in_port_type& parent_ )
-        : base_type( name_, parent_ ), m_traces( 0 )  
+        : base_type( name_, parent_ ), m_traces( 0 )
         {}
 
     explicit sc_in( inout_port_type& parent_ )
@@ -1132,13 +1132,13 @@ class sc_in<sc_dt::sc_biguint<W> > :
             }
         }
 
-    virtual inline const char* kind() const 
+    virtual inline const char* kind() const
         { return "sc_in"; }
 
 
     // called by sc_trace
     void add_trace( sc_trace_file* tf_, const std::string& name_ ) const
-        { 
+        {
             if( tf_ != 0 ) {
                 if( m_traces == 0 ) {
                     m_traces = new sc_trace_params_vec;
@@ -1193,7 +1193,7 @@ class sc_in<sc_dt::sc_biguint<W> > :
 
 
 SC_TEMPLATE
-inline std::ostream& operator << ( 
+inline std::ostream& operator << (
     std::ostream& os, const sc_in<sc_dt::sc_biguint<W> >& a )
 {
     a.read().print( os );
@@ -1204,13 +1204,13 @@ inline std::ostream& operator << (
 //==============================================================================
 // CLASS sc_inout<sc_dt::sc_biguint<W> >
 //
-// This class implements an input/output port whose target acts like an 
-// sc_dt::sc_biguint<W> data value. It is derived from the sc_unsigned_in. This class is a 
-// specialization of the generic sc_inout class to implement tailored support 
+// This class implements an input/output port whose target acts like an
+// sc_dt::sc_biguint<W> data value. It is derived from the sc_unsigned_in. This class is a
+// specialization of the generic sc_inout class to implement tailored support
 // for the sc_dt::sc_biguint<W> class.
 //==============================================================================
 SC_TEMPLATE
-class sc_inout<sc_dt::sc_biguint<W> > : 
+class sc_inout<sc_dt::sc_biguint<W> > :
     public sc_port<sc_signal_inout_if<sc_dt::sc_biguint<W> >, 1,
                    SC_ONE_OR_MORE_BOUND>,
     public sc_dt::sc_value_base
@@ -1231,10 +1231,10 @@ class sc_inout<sc_dt::sc_biguint<W> > :
 
     // bind methods and operators:
 
-    void bind( const inout_if_type& interface_ ) 
-        { sc_port_base::bind( CCAST<inout_if_type&>( interface_) ); }
+    void bind( const inout_if_type& interface_ )
+        { sc_port_base::bind( const_cast<inout_if_type&>( interface_) ); }
     void operator () ( const inout_if_type& interface_ )
-        { sc_port_base::bind( CCAST<inout_if_type&>( interface_) ); }
+        { sc_port_base::bind( const_cast<inout_if_type&>( interface_) ); }
     void bind( inout_port_type& parent_ )
         { sc_port_base::bind(parent_); }
     void operator () ( inout_port_type& parent_ )
@@ -1245,16 +1245,16 @@ class sc_inout<sc_dt::sc_biguint<W> > :
     virtual inline int vbind( sc_interface& interface_ )
         {
             return sc_port_b<if_type>::vbind( interface_ );
-        }       
+        }
     virtual inline int vbind( sc_port_base& parent_ )
         {
-            inout_port_type* inout_parent = DCAST<inout_port_type*>( &parent_ );
+            inout_port_type* inout_parent = dynamic_cast<inout_port_type*>( &parent_ );
             if( inout_parent != 0 ) {
                 sc_port_base::bind( *inout_parent );
                 return 0;
             }
             // type mismatch
-            return 2;     
+            return 2;
         }
 
 
@@ -1273,7 +1273,7 @@ class sc_inout<sc_dt::sc_biguint<W> > :
         : base_type( interface_ ), m_init_val_p(0), m_traces( 0 )
         {}
 
-    sc_inout( const char* name_, inout_if_type& interface_ )     
+    sc_inout( const char* name_, inout_if_type& interface_ )
         : base_type( name_, interface_ ), m_init_val_p(0), m_traces( 0 )
         {}
 
@@ -1282,7 +1282,7 @@ class sc_inout<sc_dt::sc_biguint<W> > :
         {}
 
     sc_inout( const char* name_, inout_port_type& parent_ )
-        : base_type( name_, parent_ ), m_init_val_p(0), m_traces( 0 )  
+        : base_type( name_, parent_ ), m_init_val_p(0), m_traces( 0 )
         {}
 
     sc_inout( this_type& parent_ )
@@ -1307,9 +1307,9 @@ class sc_inout<sc_dt::sc_biguint<W> > :
         { return (*this)->read()[i]; }
     sc_dt::sc_unsigned_bitref_r bit( int i ) const
         { return (*this)->read()[i]; }
-    sc_unsigned_sigref& operator [] ( int i ) 
+    sc_unsigned_sigref& operator [] ( int i )
         { return (*this)->select_part(i,i); }
-    sc_unsigned_sigref& bit( int i ) 
+    sc_unsigned_sigref& bit( int i )
         { return (*this)->select_part(i,i); }
     sc_dt::sc_unsigned_subref_r operator () ( int left, int right ) const
         { return (*this)->read()(left,right); }
@@ -1395,14 +1395,14 @@ class sc_inout<sc_dt::sc_biguint<W> > :
             }
         }
 
-    virtual inline const char* kind() const 
+    virtual inline const char* kind() const
         { return "sc_inout"; }
 
     // value initialization
 
     inline void initialize( const sc_dt::sc_biguint<W>& value_ )
     {
-        inout_if_type* iface = DCAST<inout_if_type*>( this->get_interface() );     
+        inout_if_type* iface = dynamic_cast<inout_if_type*>( this->get_interface() );
         if( iface != 0 ) {
             iface->write( value_ );
         } else {
@@ -1416,7 +1416,7 @@ class sc_inout<sc_dt::sc_biguint<W> > :
 
     // called by sc_trace
     void add_trace( sc_trace_file* tf_, const std::string& name_ ) const
-        { 
+        {
             if( tf_ != 0 ) {
                 if( m_traces == 0 ) {
                     m_traces = new sc_trace_params_vec;
@@ -1474,7 +1474,7 @@ class sc_inout<sc_dt::sc_biguint<W> > :
         { (*this)->write((sc_dt::uint64)new_val); }
     template<typename T>
     inline void operator = ( const sc_dt::sc_generic_base<T>& new_val )
-		{ 
+		{
 			sc_dt::sc_unsigned temp(W);
 			new_val->to_sc_unsigned(temp);
             (*this)->write(temp);
@@ -1529,7 +1529,7 @@ class sc_inout<sc_dt::sc_biguint<W> > :
 
 
 SC_TEMPLATE
-inline std::ostream& operator << ( 
+inline std::ostream& operator << (
     std::ostream& os, const sc_inout<sc_dt::sc_biguint<W> >& a )
 {
     a.read().print( os );
@@ -1540,7 +1540,7 @@ inline std::ostream& operator << (
 //==============================================================================
 // CLASS sc_out<sc_dt::sc_biguint<W> >
 //
-// This class implements an output port whose target acts like an 
+// This class implements an output port whose target acts like an
 // sc_dt::sc_biguint<W> data value. This class is a derivation of sc_inout, since
 // output ports are really no different from input/output ports.
 //==============================================================================
@@ -1625,7 +1625,7 @@ class sc_out<sc_dt::sc_biguint<W> > : public sc_inout<sc_dt::sc_biguint<W> >
         { (*this)->write((sc_dt::uint64)new_val); }
     template<typename T>
     inline void operator = ( const sc_dt::sc_generic_base<T>& new_val )
-		{ 
+		{
 			sc_dt::sc_unsigned temp(W);
 			new_val->to_sc_unsigned(temp);
             (*this)->write(temp);
@@ -1655,7 +1655,7 @@ class sc_out<sc_dt::sc_biguint<W> > : public sc_inout<sc_dt::sc_biguint<W> >
 //     left_  =  left-most bit in selection.
 //     right_ =  right-most bit in selection.
 //------------------------------------------------------------------------------
-inline void sc_unsigned_sigref::initialize( 
+inline void sc_unsigned_sigref::initialize(
 	sc_unsigned_part_if* if_p, int left_, int right_ )
 {
     m_if_p = if_p;
@@ -1684,28 +1684,28 @@ inline void sc_unsigned_sigref::operator = ( const char* v )
 }
 
 inline void sc_unsigned_sigref:: operator = ( sc_dt::int64 v )
-{ 
-    *this = (sc_dt::uint64)v; 
+{
+    *this = (sc_dt::uint64)v;
 }
 
 inline void sc_unsigned_sigref:: operator = ( int v )
-{ 
-    *this = (sc_dt::uint64)v; 
+{
+    *this = (sc_dt::uint64)v;
 }
 
 inline void sc_unsigned_sigref:: operator = ( long v )
-{ 
-    *this = (sc_dt::uint64)v; 
+{
+    *this = (sc_dt::uint64)v;
 }
 
 inline void sc_unsigned_sigref:: operator = ( unsigned int v )
-{ 
-    *this = (sc_dt::uint64)v; 
+{
+    *this = (sc_dt::uint64)v;
 }
 
 inline void sc_unsigned_sigref:: operator = ( unsigned long v )
-{ 
-    *this = (sc_dt::uint64)v; 
+{
+    *this = (sc_dt::uint64)v;
 }
 
 void sc_unsigned_sigref::operator = ( const sc_unsigned_sigref& v )
@@ -1715,19 +1715,19 @@ void sc_unsigned_sigref::operator = ( const sc_unsigned_sigref& v )
 
 
 inline void sc_unsigned_sigref:: operator = ( const sc_dt::sc_signed& v )
-{ 
+{
 	m_if_p->write_part( v, m_left, m_right );
 }
 
 inline void sc_unsigned_sigref:: operator = ( const sc_dt::sc_unsigned& v )
-{ 
+{
 	m_if_p->write_part( v, m_left, m_right );
 }
 
 template<typename T>
-inline void sc_unsigned_sigref:: operator = ( 
+inline void sc_unsigned_sigref:: operator = (
 	const sc_dt::sc_generic_base<T>& v )
-{ 
+{
 	sc_dt::sc_unsigned temp(m_left-m_right+1);
     v->to_sc_unsigned(temp);
 	m_if_p->write_part( temp, m_left, m_right );
@@ -1783,9 +1783,9 @@ void sc_unsigned_part_if::write_part( sc_dt::uint64 v, int /*left*/, int /*right
 {
     SC_REPORT_ERROR( SC_ID_OPERATION_ON_NON_SPECIALIZED_SIGNAL_, "int" );
 }
-void sc_unsigned_part_if::write_part( 
+void sc_unsigned_part_if::write_part(
     const sc_dt::sc_signed& v, int /*left*/, int /*right*/ )
-{   
+{
     SC_REPORT_ERROR( SC_ID_OPERATION_ON_NON_SPECIALIZED_SIGNAL_, "int" );
 }
 void sc_unsigned_part_if::write_part(
@@ -1808,7 +1808,7 @@ void sc_unsigned_part_if::write_part(
 void sc_unsigned_sigref::concat_set(sc_dt::int64 src, int low_i)
 {
     sc_dt::int64 tmp;
-    if ( low_i < 63 ) 
+    if ( low_i < 63 )
         tmp = src >> low_i;
     else
         tmp = (src < 0) ? -1 : 0;
